@@ -330,7 +330,7 @@ def do_change_proj(args):
             current_index = (current_index - 1 + len(templ_list)) % len(templ_list)
         
         meta["current-index"] = current_index
-        return extract_series_templ(meta, current_dir, args.raw, args.download)
+        return extract_series_templ(meta, current_dir, args.raw, args.download, args.cuda, args.trt)
 
     index_names_map = []
     for index, (templ_name, templ_descript) in enumerate(templ_list):
