@@ -17,7 +17,21 @@ def filter_content(content, variable_template):
     return content, found_variable
 
 
-def process_code_template(proj_dir, namelist, variable_template):
+def inv_filter_content(content, variable_template):
+    found_variable = False
+    for k, v in variable_template:
+        key = "${@" + k + "}"
+        if not found_variable:
+            if content.find(v) == -1:
+                continue
+            
+            found_variable = True
+
+        content = content.replace(v, key)
+    return content, found_variable
+
+
+def process_code_template(proj_dir, namelist, variable_template, filter_func=filter_content):
 
     for file in namelist:
         if proj_dir is None:
@@ -32,7 +46,7 @@ def process_code_template(proj_dir, namelist, variable_template):
                 continue
             
             content = open(full_path, "r").read()
-            new_content, found_variable = filter_content(content, variable_template)
+            new_content, found_variable = filter_func(content, variable_template)
             if found_variable:
                 print(f"Process variables {full_path}")
                 open(full_path, "w").write(new_content)
